<div class="card shadow-sm  border-light mb-3">
    <div class="card-header">
        <h5 class="card-title">Query detail</h5>
    </div>
    <div class="card-body">
      <code id="formatted_sql_query">
          {{ sonar_query.sql|safe }}
      </code>
    </div>
</div>