{% extends "django_sonar/layouts/auth.html" %}

{% block content %}
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-6">
            <h1 class="text-center mt-5">
                <i class="bi bi-broadcast me-1"></i>Django Sonar
            </h1>
            <div class="card shadow-sm  mt-5">
                <div class="card-body text-center">
                    <h5 class="card-title text-danger">Access denied</h5>
                    <div class="mt-3">
                        The current user doesn't have permission to access this page.
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
{% endblock %}