{% extends "django_sonar/layouts/auth.html" %}

{% block content %}
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-4">
            <h1 class="text-center mt-5">
                <i class="bi bi-broadcast me-1"></i>Django Sonar
            </h1>
            <div class="card shadow-sm  mt-5">
                <div class="card-body">
                    <h5 class="card-title text-center">Login</h5>
                    <form method="post">
                        {% csrf_token %}
                        <div class="mb-3">
                            <label for="username" class="form-label">Username</label>
                            <input type="text" class="form-control" id="username" name="username" required>
                        </div>
                        <div class="mb-3">
                            <label for="password" class="form-label">Password</label>
                            <input type="password" class="form-control" id="password" name="password" required>
                        </div>
                        <button type="submit" class="btn btn-primary">Login</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>
{% endblock %}