<div class="card shadow-sm border-light">
    <div class="card-header">
        <h5 class="card-title">Signals</h5>
    </div>
    <div class="card-body">
        <div class="text-light-grey">Soon™</div>
    </div>
</div>